import _win32typing

def CoInternetCreateSecurityManager(reserved, /) -> _win32typing.PyIInternetSecurityManager: ...
def CoInternetIsFeatureEnabled(flags, /): ...
def CoInternetSetFeatureEnabled(flags, enable, /): ...

FEATURE_ADDON_MANAGEMENT: int
FEATURE_BEHAVIORS: int
FEATURE_DISABLE_MK_PROTOCOL: int
FEATURE_ENTRY_COUNT: int
FEATURE_GET_URL_DOM_FILEPATH_UNENCODED: int
FEATURE_HTTP_USERNAME_PASSWORD_DISABLE: int
FEATURE_LOCALMACHINE_LOCKDOWN: int
FEATURE_MIME_HANDLING: int
FEATURE_MIME_SNIFFING: int
FEATURE_OBJECT_CACHING: int
FEATURE_PROTOCOL_LOCKDOWN: int
FEATURE_RESTRICT_ACTIVEXINSTALL: int
FEATURE_RESTRICT_FILEDOWNLOAD: int
FEATURE_SAFE_BINDTOOBJECT: int
FEATURE_SECURITYBAND: int
FEATURE_UNC_SAVEDFILECHECK: int
FEATURE_VALIDATE_NAVIGATE_URL: int
FEATURE_WEBOC_POPUPMANAGEMENT: int
FEATURE_WINDOW_RESTRICTIONS: int
FEATURE_ZONE_ELEVATION: int
GET_FEATURE_FROM_PROCESS: int
GET_FEATURE_FROM_REGISTRY: int
GET_FEATURE_FROM_THREAD: int
GET_FEATURE_FROM_THREAD_INTERNET: int
GET_FEATURE_FROM_THREAD_INTRANET: int
GET_FEATURE_FROM_THREAD_LOCALMACHINE: int
GET_FEATURE_FROM_THREAD_RESTRICTED: int
GET_FEATURE_FROM_THREAD_TRUSTED: int
IID_IDocHostUIHandler: _win32typing.PyIID
IID_IHTMLOMWindowServices: _win32typing.PyIID
IID_IInternetBindInfo: _win32typing.PyIID
IID_IInternetPriority: _win32typing.PyIID
IID_IInternetProtocol: _win32typing.PyIID
IID_IInternetProtocolInfo: _win32typing.PyIID
IID_IInternetProtocolRoot: _win32typing.PyIID
IID_IInternetProtocolSink: _win32typing.PyIID
IID_IInternetSecurityManager: _win32typing.PyIID
SET_FEATURE_IN_REGISTRY: int
SET_FEATURE_ON_PROCESS: int
SET_FEATURE_ON_THREAD: int
SET_FEATURE_ON_THREAD_INTERNET: int
SET_FEATURE_ON_THREAD_INTRANET: int
SET_FEATURE_ON_THREAD_LOCALMACHINE: int
SET_FEATURE_ON_THREAD_RESTRICTED: int
SET_FEATURE_ON_THREAD_TRUSTED: int



import _win32typing

def OpenThemeData(hwnd: int, pszClasslist: str, /) -> _win32typing.PyHTHEME: ...
def CloseThemeData(hTheme: _win32typing.PyHTHEME, /) -> None: ...
def DrawThemeBackground(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pRect, pClipRect, /) -> None: ...
def DrawThemeText(
    hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pszText: str, dwCharCount, dwTextFlags, dwTextFlags2, pRect, /
) -> None: ...
def GetThemeBackgroundContentRect(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pBoundingRect, /): ...
def GetThemeBackgroundExtent(hTheme: _win32typing.PyHTHEME, hdc, iPartId, iStateId, pContentRect, /): ...
def IsThemeActive() -> int: ...
def IsAppThemed() -> int: ...
def GetWindowTheme(hwnd: int, /) -> _win32typing.PyHTHEME: ...
def EnableThemeDialogTexture(hdlg, dwFlags, /) -> None: ...
def IsThemeDialogTextureEnabled(hdlg: int | None, /) -> bool: ...
def GetThemeAppProperties(): ...
def EnableTheming(fEnable, /) -> None: ...
def SetWindowTheme(hwnd: int, pszSubAppName: str, pszSubIdlist: str, /) -> None: ...
def GetCurrentThemeName() -> tuple[str, str, str]: ...

ETDT_DISABLE: int
ETDT_ENABLE: int
ETDT_ENABLETAB: int
ETDT_USETABTEXTURE: int
UNICODE: int



import _win32typing

def CTL_CODE(DeviceType: int, Function: int, Method: int, Access: int) -> int: ...
def DEVICE_TYPE_FROM_CTL_CODE(ctrlCode: int) -> int: ...

FILE_DEVICE_BEEP: int
FILE_DEVICE_CD_ROM: int
FILE_DEVICE_CD_ROM_FILE_SYSTEM: int
FILE_DEVICE_CONTROLLER: int
FILE_DEVICE_DATALINK: int
FILE_DEVICE_DFS: int
FILE_DEVICE_DISK: int
FILE_DEVICE_DISK_FILE_SYSTEM: int
FILE_DEVICE_FILE_SYSTEM: int
FILE_DEVICE_INPORT_PORT: int
FILE_DEVICE_KEYBOARD: int
FILE_DEVICE_MAILSLOT: int
FILE_DEVICE_MIDI_IN: int
FILE_DEVICE_MIDI_OUT: int
FILE_DEVICE_MOUSE: int
FILE_DEVICE_MULTI_UNC_PROVIDER: int
FILE_DEVICE_NAMED_PIPE: int
FILE_DEVICE_NETWORK: int
FILE_DEVICE_NETWORK_BROWSER: int
FILE_DEVICE_NETWORK_FILE_SYSTEM: int
FILE_DEVICE_NULL: int
FILE_DEVICE_PARALLEL_PORT: int
FILE_DEVICE_PHYSICAL_NETCARD: int
FILE_DEVICE_PRINTER: int
FILE_DEVICE_SCANNER: int
FILE_DEVICE_SERIAL_MOUSE_PORT: int
FILE_DEVICE_SERIAL_PORT: int
FILE_DEVICE_SCREEN: int
FILE_DEVICE_SOUND: int
FILE_DEVICE_STREAMS: int
FILE_DEVICE_TAPE: int
FILE_DEVICE_TAPE_FILE_SYSTEM: int
FILE_DEVICE_TRANSPORT: int
FILE_DEVICE_UNKNOWN: int
FILE_DEVICE_VIDEO: int
FILE_DEVICE_VIRTUAL_DISK: int
FILE_DEVICE_WAVE_IN: int
FILE_DEVICE_WAVE_OUT: int
FILE_DEVICE_8042_PORT: int
FILE_DEVICE_NETWORK_REDIRECTOR: int
FILE_DEVICE_BATTERY: int
FILE_DEVICE_BUS_EXTENDER: int
FILE_DEVICE_MODEM: int
FILE_DEVICE_VDM: int
FILE_DEVICE_MASS_STORAGE: int
FILE_DEVICE_SMB: int
FILE_DEVICE_KS: int
FILE_DEVICE_CHANGER: int
FILE_DEVICE_SMARTCARD: int
FILE_DEVICE_ACPI: int
FILE_DEVICE_DVD: int
FILE_DEVICE_FULLSCREEN_VIDEO: int
FILE_DEVICE_DFS_FILE_SYSTEM: int
FILE_DEVICE_DFS_VOLUME: int
FILE_DEVICE_SERENUM: int
FILE_DEVICE_TERMSRV: int
FILE_DEVICE_KSEC: int
FILE_DEVICE_FIPS: int
FILE_DEVICE_INFINIBAND: int
METHOD_BUFFERED: int
METHOD_IN_DIRECT: int
METHOD_OUT_DIRECT: int
METHOD_NEITHER: int
METHOD_DIRECT_TO_HARDWARE: int
METHOD_DIRECT_FROM_HARDWARE: int
FILE_ANY_ACCESS: int
FILE_SPECIAL_ACCESS: int
FILE_READ_ACCESS: int
FILE_WRITE_ACCESS: int
IOCTL_STORAGE_BASE: int
RECOVERED_WRITES_VALID: int
UNRECOVERED_WRITES_VALID: int
RECOVERED_READS_VALID: int
UNRECOVERED_READS_VALID: int
WRITE_COMPRESSION_INFO_VALID: int
READ_COMPRESSION_INFO_VALID: int
TAPE_RETURN_STATISTICS: int
TAPE_RETURN_ENV_INFO: int
TAPE_RESET_STATISTICS: int
MEDIA_ERASEABLE: int
MEDIA_WRITE_ONCE: int
MEDIA_READ_ONLY: int
MEDIA_READ_WRITE: int
MEDIA_WRITE_PROTECTED: int
MEDIA_CURRENTLY_MOUNTED: int
IOCTL_DISK_BASE: int
PARTITION_ENTRY_UNUSED: int
PARTITION_FAT_12: int
PARTITION_XENIX_1: int
PARTITION_XENIX_2: int
PARTITION_FAT_16: int
PARTITION_EXTENDED: int
PARTITION_HUGE: int
PARTITION_IFS: int
PARTITION_OS2BOOTMGR: int
PARTITION_FAT32: int
PARTITION_FAT32_XINT13: int
PARTITION_XINT13: int
PARTITION_XINT13_EXTENDED: int
PARTITION_PREP: int
PARTITION_LDM: int
PARTITION_UNIX: int
VALID_NTFT: int
PARTITION_NTFT: int
GPT_ATTRIBUTE_PLATFORM_REQUIRED: int
GPT_BASIC_DATA_ATTRIBUTE_NO_DRIVE_LETTER: int
GPT_BASIC_DATA_ATTRIBUTE_HIDDEN: int
GPT_BASIC_DATA_ATTRIBUTE_SHADOW_COPY: int
GPT_BASIC_DATA_ATTRIBUTE_READ_ONLY: int
HIST_NO_OF_BUCKETS: int
DISK_LOGGING_START: int
DISK_LOGGING_STOP: int
DISK_LOGGING_DUMP: int
DISK_BINNING: int
CAP_ATA_ID_CMD: int
CAP_ATAPI_ID_CMD: int
CAP_SMART_CMD: int
ATAPI_ID_CMD: int
ID_CMD: int
SMART_CMD: int
SMART_CYL_LOW: int
SMART_CYL_HI: int
SMART_NO_ERROR: int
SMART_IDE_ERROR: int
SMART_INVALID_FLAG: int
SMART_INVALID_COMMAND: int
SMART_INVALID_BUFFER: int
SMART_INVALID_DRIVE: int
SMART_INVALID_IOCTL: int
SMART_ERROR_NO_MEM: int
SMART_INVALID_REGISTER: int
SMART_NOT_SUPPORTED: int
SMART_NO_IDE_DEVICE: int
SMART_OFFLINE_ROUTINE_OFFLINE: int
SMART_SHORT_SELFTEST_OFFLINE: int
SMART_EXTENDED_SELFTEST_OFFLINE: int
SMART_ABORT_OFFLINE_SELFTEST: int
SMART_SHORT_SELFTEST_CAPTIVE: int
SMART_EXTENDED_SELFTEST_CAPTIVE: int
READ_ATTRIBUTE_BUFFER_SIZE: int
IDENTIFY_BUFFER_SIZE: int
READ_THRESHOLD_BUFFER_SIZE: int
SMART_LOG_SECTOR_SIZE: int
READ_ATTRIBUTES: int
READ_THRESHOLDS: int
ENABLE_DISABLE_AUTOSAVE: int
SAVE_ATTRIBUTE_VALUES: int
EXECUTE_OFFLINE_DIAGS: int
SMART_READ_LOG: int
SMART_WRITE_LOG: int
ENABLE_SMART: int
DISABLE_SMART: int
RETURN_SMART_STATUS: int
ENABLE_DISABLE_AUTO_OFFLINE: int
IOCTL_CHANGER_BASE: int
MAX_VOLUME_ID_SIZE: int
MAX_VOLUME_TEMPLATE_SIZE: int
VENDOR_ID_LENGTH: int
PRODUCT_ID_LENGTH: int
REVISION_LENGTH: int
SERIAL_NUMBER_LENGTH: int
CHANGER_BAR_CODE_SCANNER_INSTALLED: int
CHANGER_INIT_ELEM_STAT_WITH_RANGE: int
CHANGER_CLOSE_IEPORT: int
CHANGER_OPEN_IEPORT: int
CHANGER_STATUS_NON_VOLATILE: int
CHANGER_EXCHANGE_MEDIA: int
CHANGER_CLEANER_SLOT: int
CHANGER_LOCK_UNLOCK: int
CHANGER_CARTRIDGE_MAGAZINE: int
CHANGER_MEDIUM_FLIP: int
CHANGER_POSITION_TO_ELEMENT: int
CHANGER_REPORT_IEPORT_STATE: int
CHANGER_STORAGE_DRIVE: int
CHANGER_STORAGE_IEPORT: int
CHANGER_STORAGE_SLOT: int
CHANGER_STORAGE_TRANSPORT: int
CHANGER_DRIVE_CLEANING_REQUIRED: int
CHANGER_PREDISMOUNT_EJECT_REQUIRED: int
CHANGER_CLEANER_ACCESS_NOT_VALID: int
CHANGER_PREMOUNT_EJECT_REQUIRED: int
CHANGER_VOLUME_IDENTIFICATION: int
CHANGER_VOLUME_SEARCH: int
CHANGER_VOLUME_ASSERT: int
CHANGER_VOLUME_REPLACE: int
CHANGER_VOLUME_UNDEFINE: int
CHANGER_SERIAL_NUMBER_VALID: int
CHANGER_DEVICE_REINITIALIZE_CAPABLE: int
CHANGER_KEYPAD_ENABLE_DISABLE: int
CHANGER_DRIVE_EMPTY_ON_DOOR_ACCESS: int
CHANGER_RESERVED_BIT: int
CHANGER_PREDISMOUNT_ALIGN_TO_SLOT: int
CHANGER_PREDISMOUNT_ALIGN_TO_DRIVE: int
CHANGER_CLEANER_AUTODISMOUNT: int
CHANGER_TRUE_EXCHANGE_CAPABLE: int
CHANGER_SLOTS_USE_TRAYS: int
CHANGER_RTN_MEDIA_TO_ORIGINAL_ADDR: int
CHANGER_CLEANER_OPS_NOT_SUPPORTED: int
CHANGER_IEPORT_USER_CONTROL_OPEN: int
CHANGER_IEPORT_USER_CONTROL_CLOSE: int
CHANGER_MOVE_EXTENDS_IEPORT: int
CHANGER_MOVE_RETRACTS_IEPORT: int
CHANGER_TO_TRANSPORT: int
CHANGER_TO_SLOT: int
CHANGER_TO_IEPORT: int
CHANGER_TO_DRIVE: int
LOCK_UNLOCK_IEPORT: int
LOCK_UNLOCK_DOOR: int
LOCK_UNLOCK_KEYPAD: int
LOCK_ELEMENT: int
UNLOCK_ELEMENT: int
EXTEND_IEPORT: int
RETRACT_IEPORT: int
ELEMENT_STATUS_FULL: int
ELEMENT_STATUS_IMPEXP: int
ELEMENT_STATUS_EXCEPT: int
ELEMENT_STATUS_ACCESS: int
ELEMENT_STATUS_EXENAB: int
ELEMENT_STATUS_INENAB: int
ELEMENT_STATUS_PRODUCT_DATA: int
ELEMENT_STATUS_LUN_VALID: int
ELEMENT_STATUS_ID_VALID: int
ELEMENT_STATUS_NOT_BUS: int
ELEMENT_STATUS_INVERT: int
ELEMENT_STATUS_SVALID: int
ELEMENT_STATUS_PVOLTAG: int
ELEMENT_STATUS_AVOLTAG: int
ERROR_LABEL_UNREADABLE: int
ERROR_LABEL_QUESTIONABLE: int
ERROR_SLOT_NOT_PRESENT: int
ERROR_DRIVE_NOT_INSTALLED: int
ERROR_TRAY_MALFUNCTION: int
ERROR_INIT_STATUS_NEEDED: int
ERROR_UNHANDLED_ERROR: int
SEARCH_ALL: int
SEARCH_PRIMARY: int
SEARCH_ALTERNATE: int
SEARCH_ALL_NO_SEQ: int
SEARCH_PRI_NO_SEQ: int
SEARCH_ALT_NO_SEQ: int
ASSERT_PRIMARY: int
ASSERT_ALTERNATE: int
REPLACE_PRIMARY: int
REPLACE_ALTERNATE: int
UNDEFINE_PRIMARY: int
UNDEFINE_ALTERNATE: int
USN_PAGE_SIZE: int
USN_REASON_DATA_OVERWRITE: int
USN_REASON_DATA_EXTEND: int
USN_REASON_DATA_TRUNCATION: int
USN_REASON_NAMED_DATA_OVERWRITE: int
USN_REASON_NAMED_DATA_EXTEND: int
USN_REASON_NAMED_DATA_TRUNCATION: int
USN_REASON_FILE_CREATE: int
USN_REASON_FILE_DELETE: int
USN_REASON_EA_CHANGE: int
USN_REASON_SECURITY_CHANGE: int
USN_REASON_RENAME_OLD_NAME: int
USN_REASON_RENAME_NEW_NAME: int
USN_REASON_INDEXABLE_CHANGE: int
USN_REASON_BASIC_INFO_CHANGE: int
USN_REASON_HARD_LINK_CHANGE: int
USN_REASON_COMPRESSION_CHANGE: int
USN_REASON_ENCRYPTION_CHANGE: int
USN_REASON_OBJECT_ID_CHANGE: int
USN_REASON_REPARSE_POINT_CHANGE: int
USN_REASON_STREAM_CHANGE: int
USN_REASON_TRANSACTED_CHANGE: int
USN_REASON_CLOSE: int
USN_DELETE_FLAG_DELETE: int
USN_DELETE_FLAG_NOTIFY: int
USN_DELETE_VALID_FLAGS: int
USN_SOURCE_DATA_MANAGEMENT: int
USN_SOURCE_AUXILIARY_DATA: int
USN_SOURCE_REPLICATION_MANAGEMENT: int
MARK_HANDLE_PROTECT_CLUSTERS: int
MARK_HANDLE_TXF_SYSTEM_LOG: int
MARK_HANDLE_NOT_TXF_SYSTEM_LOG: int
VOLUME_IS_DIRTY: int
VOLUME_UPGRADE_SCHEDULED: int
VOLUME_SESSION_OPEN: int
FILE_PREFETCH_TYPE_FOR_CREATE: int
FILE_PREFETCH_TYPE_FOR_DIRENUM: int
FILE_PREFETCH_TYPE_FOR_CREATE_EX: int
FILE_PREFETCH_TYPE_FOR_DIRENUM_EX: int
FILE_PREFETCH_TYPE_MAX: int
FILESYSTEM_STATISTICS_TYPE_NTFS: int
FILESYSTEM_STATISTICS_TYPE_FAT: int
FILE_SET_ENCRYPTION: int
FILE_CLEAR_ENCRYPTION: int
STREAM_SET_ENCRYPTION: int
STREAM_CLEAR_ENCRYPTION: int
MAXIMUM_ENCRYPTION_VALUE: int
ENCRYPTION_FORMAT_DEFAULT: int
COMPRESSION_FORMAT_SPARSE: int
COPYFILE_SIS_LINK: int
COPYFILE_SIS_REPLACE: int
COPYFILE_SIS_FLAGS: int
WMI_DISK_GEOMETRY_GUID: _win32typing.PyIID
GUID_DEVINTERFACE_CDROM: _win32typing.PyIID
GUID_DEVINTERFACE_FLOPPY: _win32typing.PyIID
GUID_DEVINTERFACE_SERENUM_BUS_ENUMERATOR: _win32typing.PyIID
GUID_DEVINTERFACE_COMPORT: _win32typing.PyIID
GUID_DEVINTERFACE_DISK: _win32typing.PyIID
GUID_DEVINTERFACE_STORAGEPORT: _win32typing.PyIID
GUID_DEVINTERFACE_CDCHANGER: _win32typing.PyIID
GUID_DEVINTERFACE_PARTITION: _win32typing.PyIID
GUID_DEVINTERFACE_VOLUME: _win32typing.PyIID
GUID_DEVINTERFACE_WRITEONCEDISK: _win32typing.PyIID
GUID_DEVINTERFACE_TAPE: _win32typing.PyIID
GUID_DEVINTERFACE_MEDIUMCHANGER: _win32typing.PyIID
GUID_SERENUM_BUS_ENUMERATOR: int
GUID_CLASS_COMPORT: int
DiskClassGuid: int
CdRomClassGuid: int
PartitionClassGuid: int
TapeClassGuid: int
WriteOnceDiskClassGuid: int
VolumeClassGuid: int
MediumChangerClassGuid: int
FloppyClassGuid: int
CdChangerClassGuid: int
StoragePortClassGuid: int
IOCTL_STORAGE_CHECK_VERIFY: int
IOCTL_STORAGE_CHECK_VERIFY2: int
IOCTL_STORAGE_MEDIA_REMOVAL: int
IOCTL_STORAGE_EJECT_MEDIA: int
IOCTL_STORAGE_LOAD_MEDIA: int
IOCTL_STORAGE_LOAD_MEDIA2: int
IOCTL_STORAGE_RESERVE: int
IOCTL_STORAGE_RELEASE: int
IOCTL_STORAGE_FIND_NEW_DEVICES: int
IOCTL_STORAGE_EJECTION_CONTROL: int
IOCTL_STORAGE_MCN_CONTROL: int
IOCTL_STORAGE_GET_MEDIA_TYPES: int
IOCTL_STORAGE_GET_MEDIA_TYPES_EX: int
IOCTL_STORAGE_GET_MEDIA_SERIAL_NUMBER: int
IOCTL_STORAGE_GET_HOTPLUG_INFO: int
IOCTL_STORAGE_SET_HOTPLUG_INFO: int
IOCTL_STORAGE_RESET_BUS: int
IOCTL_STORAGE_RESET_DEVICE: int
IOCTL_STORAGE_BREAK_RESERVATION: int
IOCTL_STORAGE_GET_DEVICE_NUMBER: int
IOCTL_STORAGE_PREDICT_FAILURE: int
IOCTL_DISK_GET_DRIVE_GEOMETRY: int
IOCTL_DISK_GET_PARTITION_INFO: int
IOCTL_DISK_SET_PARTITION_INFO: int
IOCTL_DISK_GET_DRIVE_LAYOUT: int
IOCTL_DISK_SET_DRIVE_LAYOUT: int
IOCTL_DISK_VERIFY: int
IOCTL_DISK_FORMAT_TRACKS: int
IOCTL_DISK_REASSIGN_BLOCKS: int
IOCTL_DISK_PERFORMANCE: int
IOCTL_DISK_IS_WRITABLE: int
IOCTL_DISK_LOGGING: int
IOCTL_DISK_FORMAT_TRACKS_EX: int
IOCTL_DISK_HISTOGRAM_STRUCTURE: int
IOCTL_DISK_HISTOGRAM_DATA: int
IOCTL_DISK_HISTOGRAM_RESET: int
IOCTL_DISK_REQUEST_STRUCTURE: int
IOCTL_DISK_REQUEST_DATA: int
IOCTL_DISK_PERFORMANCE_OFF: int
IOCTL_DISK_CONTROLLER_NUMBER: int
SMART_GET_VERSION: int
SMART_SEND_DRIVE_COMMAND: int
SMART_RCV_DRIVE_DATA: int
IOCTL_DISK_GET_PARTITION_INFO_EX: int
IOCTL_DISK_SET_PARTITION_INFO_EX: int
IOCTL_DISK_GET_DRIVE_LAYOUT_EX: int
IOCTL_DISK_SET_DRIVE_LAYOUT_EX: int
IOCTL_DISK_CREATE_DISK: int
IOCTL_DISK_GET_LENGTH_INFO: int
IOCTL_DISK_GET_DRIVE_GEOMETRY_EX: int
IOCTL_DISK_REASSIGN_BLOCKS_EX: int
IOCTL_DISK_UPDATE_DRIVE_SIZE: int
IOCTL_DISK_GROW_PARTITION: int
IOCTL_DISK_GET_CACHE_INFORMATION: int
IOCTL_DISK_SET_CACHE_INFORMATION: int
OBSOLETE_IOCTL_STORAGE_RESET_BUS: int
OBSOLETE_IOCTL_STORAGE_RESET_DEVICE: int
OBSOLETE_DISK_GET_WRITE_CACHE_STATE: int
IOCTL_DISK_GET_WRITE_CACHE_STATE: int
IOCTL_DISK_DELETE_DRIVE_LAYOUT: int
IOCTL_DISK_UPDATE_PROPERTIES: int
IOCTL_DISK_FORMAT_DRIVE: int
IOCTL_DISK_SENSE_DEVICE: int
IOCTL_DISK_CHECK_VERIFY: int
IOCTL_DISK_MEDIA_REMOVAL: int
IOCTL_DISK_EJECT_MEDIA: int
IOCTL_DISK_LOAD_MEDIA: int
IOCTL_DISK_RESERVE: int
IOCTL_DISK_RELEASE: int
IOCTL_DISK_FIND_NEW_DEVICES: int
IOCTL_DISK_GET_MEDIA_TYPES: int
DISK_HISTOGRAM_SIZE: int
HISTOGRAM_BUCKET_SIZE: int
IOCTL_CHANGER_GET_PARAMETERS: int
IOCTL_CHANGER_GET_STATUS: int
IOCTL_CHANGER_GET_PRODUCT_DATA: int
IOCTL_CHANGER_SET_ACCESS: int
IOCTL_CHANGER_GET_ELEMENT_STATUS: int
IOCTL_CHANGER_INITIALIZE_ELEMENT_STATUS: int
IOCTL_CHANGER_SET_POSITION: int
IOCTL_CHANGER_EXCHANGE_MEDIUM: int
IOCTL_CHANGER_MOVE_MEDIUM: int
IOCTL_CHANGER_REINITIALIZE_TRANSPORT: int
IOCTL_CHANGER_QUERY_VOLUME_TAGS: int
IOCTL_SERIAL_LSRMST_INSERT: int
IOCTL_SERENUM_EXPOSE_HARDWARE: int
IOCTL_SERENUM_REMOVE_HARDWARE: int
IOCTL_SERENUM_PORT_DESC: int
IOCTL_SERENUM_GET_PORT_NAME: int
SERIAL_LSRMST_ESCAPE: int
SERIAL_LSRMST_LSR_DATA: int
SERIAL_LSRMST_LSR_NODATA: int
SERIAL_LSRMST_MST: int
SERIAL_IOC_FCR_FIFO_ENABLE: int
SERIAL_IOC_FCR_RCVR_RESET: int
SERIAL_IOC_FCR_XMIT_RESET: int
SERIAL_IOC_FCR_DMA_MODE: int
SERIAL_IOC_FCR_RES1: int
SERIAL_IOC_FCR_RES2: int
SERIAL_IOC_FCR_RCVR_TRIGGER_LSB: int
SERIAL_IOC_FCR_RCVR_TRIGGER_MSB: int
SERIAL_IOC_MCR_DTR: int
SERIAL_IOC_MCR_RTS: int
SERIAL_IOC_MCR_OUT1: int
SERIAL_IOC_MCR_OUT2: int
SERIAL_IOC_MCR_LOOP: int
FSCTL_REQUEST_OPLOCK_LEVEL_1: int
FSCTL_REQUEST_OPLOCK_LEVEL_2: int
FSCTL_REQUEST_BATCH_OPLOCK: int
FSCTL_OPLOCK_BREAK_ACKNOWLEDGE: int
FSCTL_OPBATCH_ACK_CLOSE_PENDING: int
FSCTL_OPLOCK_BREAK_NOTIFY: int
FSCTL_LOCK_VOLUME: int
FSCTL_UNLOCK_VOLUME: int
FSCTL_DISMOUNT_VOLUME: int
FSCTL_IS_VOLUME_MOUNTED: int
FSCTL_IS_PATHNAME_VALID: int
FSCTL_MARK_VOLUME_DIRTY: int
FSCTL_QUERY_RETRIEVAL_POINTERS: int
FSCTL_GET_COMPRESSION: int
FSCTL_SET_COMPRESSION: int
FSCTL_MARK_AS_SYSTEM_HIVE: int
FSCTL_OPLOCK_BREAK_ACK_NO_2: int
FSCTL_INVALIDATE_VOLUMES: int
FSCTL_QUERY_FAT_BPB: int
FSCTL_REQUEST_FILTER_OPLOCK: int
FSCTL_FILESYSTEM_GET_STATISTICS: int
FSCTL_GET_NTFS_VOLUME_DATA: int
FSCTL_GET_NTFS_FILE_RECORD: int
FSCTL_GET_VOLUME_BITMAP: int
FSCTL_GET_RETRIEVAL_POINTERS: int
FSCTL_MOVE_FILE: int
FSCTL_IS_VOLUME_DIRTY: int
FSCTL_ALLOW_EXTENDED_DASD_IO: int
FSCTL_FIND_FILES_BY_SID: int
FSCTL_SET_OBJECT_ID: int
FSCTL_GET_OBJECT_ID: int
FSCTL_DELETE_OBJECT_ID: int
FSCTL_SET_REPARSE_POINT: int
FSCTL_GET_REPARSE_POINT: int
FSCTL_DELETE_REPARSE_POINT: int
FSCTL_ENUM_USN_DATA: int
FSCTL_SECURITY_ID_CHECK: int
FSCTL_READ_USN_JOURNAL: int
FSCTL_SET_OBJECT_ID_EXTENDED: int
FSCTL_CREATE_OR_GET_OBJECT_ID: int
FSCTL_SET_SPARSE: int
FSCTL_SET_ZERO_DATA: int
FSCTL_QUERY_ALLOCATED_RANGES: int
FSCTL_SET_ENCRYPTION: int
FSCTL_ENCRYPTION_FSCTL_IO: int
FSCTL_WRITE_RAW_ENCRYPTED: int
FSCTL_READ_RAW_ENCRYPTED: int
FSCTL_CREATE_USN_JOURNAL: int
FSCTL_READ_FILE_USN_DATA: int
FSCTL_WRITE_USN_CLOSE_RECORD: int
FSCTL_EXTEND_VOLUME: int
FSCTL_QUERY_USN_JOURNAL: int
FSCTL_DELETE_USN_JOURNAL: int
FSCTL_MARK_HANDLE: int
FSCTL_SIS_COPYFILE: int
FSCTL_SIS_LINK_FILES: int
FSCTL_HSM_MSG: int
FSCTL_HSM_DATA: int
FSCTL_RECALL_FILE: int
FSCTL_READ_FROM_PLEX: int
FSCTL_FILE_PREFETCH: int
FSCTL_MAKE_MEDIA_COMPATIBLE: int
FSCTL_SET_DEFECT_MANAGEMENT: int
FSCTL_QUERY_SPARING_INFO: int
FSCTL_QUERY_ON_DISK_VOLUME_INFO: int
FSCTL_SET_VOLUME_COMPRESSION_STATE: int
FSCTL_TXFS_MODIFY_RM: int
FSCTL_TXFS_QUERY_RM_INFORMATION: int
FSCTL_TXFS_ROLLFORWARD_REDO: int
FSCTL_TXFS_ROLLFORWARD_UNDO: int
FSCTL_TXFS_START_RM: int
FSCTL_TXFS_SHUTDOWN_RM: int
FSCTL_TXFS_READ_BACKUP_INFORMATION: int
FSCTL_TXFS_WRITE_BACKUP_INFORMATION: int
FSCTL_TXFS_CREATE_SECONDARY_RM: int
FSCTL_TXFS_GET_METADATA_INFO: int
FSCTL_TXFS_GET_TRANSACTED_VERSION: int
FSCTL_TXFS_CREATE_MINIVERSION: int
FSCTL_TXFS_TRANSACTION_ACTIVE: int
FSCTL_SET_ZERO_ON_DEALLOCATION: int
FSCTL_SET_REPAIR: int
FSCTL_GET_REPAIR: int
FSCTL_WAIT_FOR_REPAIR: int
FSCTL_INITIATE_REPAIR: int
FSCTL_CSC_INTERNAL: int
FSCTL_SHRINK_VOLUME: int
FSCTL_SET_SHORT_NAME_BEHAVIOR: int
FSCTL_DFSR_SET_GHOST_HANDLE_STATE: int
FSCTL_QUERY_PAGEFILE_ENCRYPTION: int
IOCTL_VOLUME_BASE: int
IOCTL_VOLUME_GET_VOLUME_DISK_EXTENTS: int
IOCTL_VOLUME_ONLINE: int
IOCTL_VOLUME_OFFLINE: int
IOCTL_VOLUME_IS_CLUSTERED: int
IOCTL_VOLUME_GET_GPT_ATTRIBUTES: int
DDS_4mm: int
MiniQic: int
Travan: int
QIC: int
MP_8mm: int
AME_8mm: int
AIT1_8mm: int
DLT: int
NCTP: int
IBM_3480: int
IBM_3490E: int
IBM_Magstar_3590: int
IBM_Magstar_MP: int
STK_DATA_D3: int
SONY_DTF: int
DV_6mm: int
DMI: int
SONY_D2: int
CLEANER_CARTRIDGE: int
CD_ROM: int
CD_R: int
CD_RW: int
DVD_ROM: int
DVD_R: int
DVD_RW: int
MO_3_RW: int
MO_5_WO: int
MO_5_RW: int
MO_5_LIMDOW: int
PC_5_WO: int
PC_5_RW: int
PD_5_RW: int
ABL_5_WO: int
PINNACLE_APEX_5_RW: int
SONY_12_WO: int
PHILIPS_12_WO: int
HITACHI_12_WO: int
CYGNET_12_WO: int
KODAK_14_WO: int
MO_NFR_525: int
NIKON_12_RW: int
IOMEGA_ZIP: int
IOMEGA_JAZ: int
SYQUEST_EZ135: int
SYQUEST_EZFLYER: int
SYQUEST_SYJET: int
AVATAR_F2: int
MP2_8mm: int
DST_S: int
DST_M: int
DST_L: int
VXATape_1: int
VXATape_2: int
STK_9840: int
LTO_Ultrium: int
LTO_Accelis: int
DVD_RAM: int
AIT_8mm: int
ADR_1: int
ADR_2: int
STK_9940: int
BusTypeUnknown: int
BusTypeScsi: int
BusTypeAtapi: int
BusTypeAta: int
BusType1394: int
BusTypeSsa: int
BusTypeFibre: int
BusTypeUsb: int
BusTypeRAID: int
BusTypeiScsi: int
BusTypeSas: int
BusTypeSata: int
BusTypeMaxReserved: int
Unknown: int
F5_1Pt2_512: int
F3_1Pt44_512: int
F3_2Pt88_512: int
F3_20Pt8_512: int
F3_720_512: int
F5_360_512: int
F5_320_512: int
F5_320_1024: int
F5_180_512: int
F5_160_512: int
RemovableMedia: int
FixedMedia: int
F3_120M_512: int
F3_640_512: int
F5_640_512: int
F5_720_512: int
F3_1Pt2_512: int
F3_1Pt23_1024: int
F5_1Pt23_1024: int
F3_128Mb_512: int
F3_230Mb_512: int
F8_256_128: int
F3_200Mb_512: int
F3_240M_512: int
F3_32M_512: int
PARTITION_STYLE_MBR: int
PARTITION_STYLE_GPT: int
PARTITION_STYLE_RAW: int
DetectNone: int
DetectInt13: int
DetectExInt13: int
EqualPriority: int
KeepPrefetchedData: int
KeepReadData: int
DiskWriteCacheNormal: int
DiskWriteCacheForceDisable: int
DiskWriteCacheDisableNotSupported: int
RequestSize: int
RequestLocation: int
DeviceProblemNone: int
DeviceProblemHardware: int
DeviceProblemCHMError: int
DeviceProblemDoorOpen: int
DeviceProblemCalibrationError: int
DeviceProblemTargetFailure: int
DeviceProblemCHMMoveError: int
DeviceProblemCHMZeroError: int
DeviceProblemCartridgeInsertError: int
DeviceProblemPositionError: int
DeviceProblemSensorError: int
DeviceProblemCartridgeEjectError: int
DeviceProblemGripperError: int
DeviceProblemDriveError: int
FILE_READ_DATA: int
FILE_WRITE_DATA: int
FSCTL_TXFS_LIST_TRANSACTIONS: int
FSCTL_TXFS_LIST_TRANSACTION_LOCKED_FILES: int



import _win32typing

def BindIFilterFromStorage(*args): ...  # incomplete
def BindIFilterFromStream(*args): ...  # incomplete
def LoadIFilter(*args): ...  # incomplete

CHUNK_EOC: int
CHUNK_EOP: int
CHUNK_EOS: int
CHUNK_EOW: int
CHUNK_NO_BREAK: int
CHUNK_TEXT: int
CHUNK_VALUE: int
FILTER_E_ACCESS: int
FILTER_E_EMBEDDING_UNAVAILABLE: int
FILTER_E_END_OF_CHUNKS: int
FILTER_E_LINK_UNAVAILABLE: int
FILTER_E_NO_MORE_TEXT: int
FILTER_E_NO_MORE_VALUES: int
FILTER_E_NO_TEXT: int
FILTER_E_NO_VALUES: int
FILTER_E_PASSWORD: int
FILTER_S_LAST_TEXT: int
IFILTER_FLAGS_OLE_PROPERTIES: int
IFILTER_INIT_APPLY_INDEX_ATTRIBUTES: int
IFILTER_INIT_APPLY_OTHER_ATTRIBUTES: int
IFILTER_INIT_CANON_HYPHENS: int
IFILTER_INIT_CANON_PARAGRAPHS: int
IFILTER_INIT_CANON_SPACES: int
IFILTER_INIT_HARD_LINE_BREAKS: int
IFILTER_INIT_INDEXING_ONLY: int
IFILTER_INIT_SEARCH_LINKS: int
IID_IFilter: _win32typing.PyIID



ISSP_LEVEL: int
ISSP_MODE: int

def SEC_SUCCESS(Status: int) -> bool: ...

SECPKG_FLAG_INTEGRITY: int
SECPKG_FLAG_PRIVACY: int
SECPKG_FLAG_TOKEN_ONLY: int
SECPKG_FLAG_DATAGRAM: int
SECPKG_FLAG_CONNECTION: int
SECPKG_FLAG_MULTI_REQUIRED: int
SECPKG_FLAG_CLIENT_ONLY: int
SECPKG_FLAG_EXTENDED_ERROR: int
SECPKG_FLAG_IMPERSONATION: int
SECPKG_FLAG_ACCEPT_WIN32_NAME: int
SECPKG_FLAG_STREAM: int
SECPKG_FLAG_NEGOTIABLE: int
SECPKG_FLAG_GSS_COMPATIBLE: int
SECPKG_FLAG_LOGON: int
SECPKG_FLAG_ASCII_BUFFERS: int
SECPKG_FLAG_FRAGMENT: int
SECPKG_FLAG_MUTUAL_AUTH: int
SECPKG_FLAG_DELEGATION: int
SECPKG_FLAG_READONLY_WITH_CHECKSUM: int
SECPKG_ID_NONE: int
SECBUFFER_VERSION: int
SECBUFFER_EMPTY: int
SECBUFFER_DATA: int
SECBUFFER_TOKEN: int
SECBUFFER_PKG_PARAMS: int
SECBUFFER_MISSING: int
SECBUFFER_EXTRA: int
SECBUFFER_STREAM_TRAILER: int
SECBUFFER_STREAM_HEADER: int
SECBUFFER_NEGOTIATION_INFO: int
SECBUFFER_PADDING: int
SECBUFFER_STREAM: int
SECBUFFER_TARGET: int
SECBUFFER_CHANNEL_BINDINGS: int
SECBUFFER_ATTRMASK: int
SECBUFFER_READONLY: int
SECBUFFER_READONLY_WITH_CHECKSUM: int
SECBUFFER_RESERVED: int
SECURITY_NATIVE_DREP: int
SECURITY_NETWORK_DREP: int
SECPKG_CRED_INBOUND: int
SECPKG_CRED_OUTBOUND: int
SECPKG_CRED_BOTH: int
SECPKG_CRED_DEFAULT: int
SECPKG_CRED_RESERVED: int
ISC_REQ_DELEGATE: int
ISC_REQ_MUTUAL_AUTH: int
ISC_REQ_REPLAY_DETECT: int
ISC_REQ_SEQUENCE_DETECT: int
ISC_REQ_CONFIDENTIALITY: int
ISC_REQ_USE_SESSION_KEY: int
ISC_REQ_PROMPT_FOR_CREDS: int
ISC_REQ_USE_SUPPLIED_CREDS: int
ISC_REQ_ALLOCATE_MEMORY: int
ISC_REQ_USE_DCE_STYLE: int
ISC_REQ_DATAGRAM: int
ISC_REQ_CONNECTION: int
ISC_REQ_CALL_LEVEL: int
ISC_REQ_FRAGMENT_SUPPLIED: int
ISC_REQ_EXTENDED_ERROR: int
ISC_REQ_STREAM: int
ISC_REQ_INTEGRITY: int
ISC_REQ_IDENTIFY: int
ISC_REQ_NULL_SESSION: int
ISC_REQ_MANUAL_CRED_VALIDATION: int
ISC_REQ_RESERVED1: int
ISC_REQ_FRAGMENT_TO_FIT: int
ISC_REQ_HTTP: int
ISC_RET_DELEGATE: int
ISC_RET_MUTUAL_AUTH: int
ISC_RET_REPLAY_DETECT: int
ISC_RET_SEQUENCE_DETECT: int
ISC_RET_CONFIDENTIALITY: int
ISC_RET_USE_SESSION_KEY: int
ISC_RET_USED_COLLECTED_CREDS: int
ISC_RET_USED_SUPPLIED_CREDS: int
ISC_RET_ALLOCATED_MEMORY: int
ISC_RET_USED_DCE_STYLE: int
ISC_RET_DATAGRAM: int
ISC_RET_CONNECTION: int
ISC_RET_INTERMEDIATE_RETURN: int
ISC_RET_CALL_LEVEL: int
ISC_RET_EXTENDED_ERROR: int
ISC_RET_STREAM: int
ISC_RET_INTEGRITY: int
ISC_RET_IDENTIFY: int
ISC_RET_NULL_SESSION: int
ISC_RET_MANUAL_CRED_VALIDATION: int
ISC_RET_RESERVED1: int
ISC_RET_FRAGMENT_ONLY: int
ASC_REQ_DELEGATE: int
ASC_REQ_MUTUAL_AUTH: int
ASC_REQ_REPLAY_DETECT: int
ASC_REQ_SEQUENCE_DETECT: int
ASC_REQ_CONFIDENTIALITY: int
ASC_REQ_USE_SESSION_KEY: int
ASC_REQ_ALLOCATE_MEMORY: int
ASC_REQ_USE_DCE_STYLE: int
ASC_REQ_DATAGRAM: int
ASC_REQ_CONNECTION: int
ASC_REQ_CALL_LEVEL: int
ASC_REQ_EXTENDED_ERROR: int
ASC_REQ_STREAM: int
ASC_REQ_INTEGRITY: int
ASC_REQ_LICENSING: int
ASC_REQ_IDENTIFY: int
ASC_REQ_ALLOW_NULL_SESSION: int
ASC_REQ_ALLOW_NON_USER_LOGONS: int
ASC_REQ_ALLOW_CONTEXT_REPLAY: int
ASC_REQ_FRAGMENT_TO_FIT: int
ASC_REQ_FRAGMENT_SUPPLIED: int
ASC_REQ_NO_TOKEN: int
ASC_RET_DELEGATE: int
ASC_RET_MUTUAL_AUTH: int
ASC_RET_REPLAY_DETECT: int
ASC_RET_SEQUENCE_DETECT: int
ASC_RET_CONFIDENTIALITY: int
ASC_RET_USE_SESSION_KEY: int
ASC_RET_ALLOCATED_MEMORY: int
ASC_RET_USED_DCE_STYLE: int
ASC_RET_DATAGRAM: int
ASC_RET_CONNECTION: int
ASC_RET_CALL_LEVEL: int
ASC_RET_THIRD_LEG_FAILED: int
ASC_RET_EXTENDED_ERROR: int
ASC_RET_STREAM: int
ASC_RET_INTEGRITY: int
ASC_RET_LICENSING: int
ASC_RET_IDENTIFY: int
ASC_RET_NULL_SESSION: int
ASC_RET_ALLOW_NON_USER_LOGONS: int
ASC_RET_ALLOW_CONTEXT_REPLAY: int
ASC_RET_FRAGMENT_ONLY: int
SECPKG_CRED_ATTR_NAMES: int
SECPKG_ATTR_SIZES: int
SECPKG_ATTR_NAMES: int
SECPKG_ATTR_LIFESPAN: int
SECPKG_ATTR_DCE_INFO: int
SECPKG_ATTR_STREAM_SIZES: int
SECPKG_ATTR_KEY_INFO: int
SECPKG_ATTR_AUTHORITY: int
SECPKG_ATTR_PROTO_INFO: int
SECPKG_ATTR_PASSWORD_EXPIRY: int
SECPKG_ATTR_SESSION_KEY: int
SECPKG_ATTR_PACKAGE_INFO: int
SECPKG_ATTR_USER_FLAGS: int
SECPKG_ATTR_NEGOTIATION_INFO: int
SECPKG_ATTR_NATIVE_NAMES: int
SECPKG_ATTR_FLAGS: int
SECPKG_ATTR_USE_VALIDATED: int
SECPKG_ATTR_CREDENTIAL_NAME: int
SECPKG_ATTR_TARGET_INFORMATION: int
SECPKG_ATTR_ACCESS_TOKEN: int
SECPKG_ATTR_TARGET: int
SECPKG_ATTR_AUTHENTICATION_ID: int
SECPKG_ATTR_REMOTE_CERT_CONTEXT: int
SECPKG_ATTR_LOCAL_CERT_CONTEXT: int
SECPKG_ATTR_ROOT_STORE: int
SECPKG_ATTR_SUPPORTED_ALGS: int
SECPKG_ATTR_CIPHER_STRENGTHS: int
SECPKG_ATTR_SUPPORTED_PROTOCOLS: int
SECPKG_ATTR_CONNECTION_INFO: int
SECPKG_ATTR_EAP_KEY_BLOCK: int
SECPKG_ATTR_MAPPED_CRED_ATTR: int
SECPKG_ATTR_SESSION_INFO: int
SECPKG_ATTR_APP_DATA: int
SECPKG_NEGOTIATION_COMPLETE: int
SECPKG_NEGOTIATION_OPTIMISTIC: int
SECPKG_NEGOTIATION_IN_PROGRESS: int
SECPKG_NEGOTIATION_DIRECT: int
SECPKG_NEGOTIATION_TRY_MULTICRED: int
SECPKG_CONTEXT_EXPORT_RESET_NEW: int
SECPKG_CONTEXT_EXPORT_DELETE_OLD: int
SECQOP_WRAP_NO_ENCRYPT: int
SECURITY_ENTRYPOINT_ANSIW: str
SECURITY_ENTRYPOINT_ANSIA: str
SECURITY_ENTRYPOINT16: str
SECURITY_ENTRYPOINT: str
SECURITY_ENTRYPOINT_ANSI: str
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION: int
SECURITY_SUPPORT_PROVIDER_INTERFACE_VERSION_2: int
SASL_OPTION_SEND_SIZE: int
SASL_OPTION_RECV_SIZE: int
SASL_OPTION_AUTHZ_STRING: int
SASL_OPTION_AUTHZ_PROCESSING: int
SEC_WINNT_AUTH_IDENTITY_ANSI: int
SEC_WINNT_AUTH_IDENTITY_UNICODE: int
SEC_WINNT_AUTH_IDENTITY_VERSION: int
SEC_WINNT_AUTH_IDENTITY_MARSHALLED: int
SEC_WINNT_AUTH_IDENTITY_ONLY: int
SECPKG_OPTIONS_TYPE_UNKNOWN: int
SECPKG_OPTIONS_TYPE_LSA: int
SECPKG_OPTIONS_TYPE_SSPI: int
SECPKG_OPTIONS_PERMANENT: int
SEC_E_INSUFFICIENT_MEMORY: int
SEC_E_INVALID_HANDLE: int
SEC_E_UNSUPPORTED_FUNCTION: int
SEC_E_TARGET_UNKNOWN: int
SEC_E_INTERNAL_ERROR: int
SEC_E_SECPKG_NOT_FOUND: int
SEC_E_NOT_OWNER: int
SEC_E_CANNOT_INSTALL: int
SEC_E_INVALID_TOKEN: int
SEC_E_CANNOT_PACK: int
SEC_E_QOP_NOT_SUPPORTED: int
SEC_E_NO_IMPERSONATION: int
SEC_E_LOGON_DENIED: int
SEC_E_UNKNOWN_CREDENTIALS: int
SEC_E_NO_CREDENTIALS: int
SEC_E_MESSAGE_ALTERED: int
SEC_E_OUT_OF_SEQUENCE: int
SEC_E_NO_AUTHENTICATING_AUTHORITY: int
SEC_I_CONTINUE_NEEDED: int
SEC_I_COMPLETE_NEEDED: int
SEC_I_COMPLETE_AND_CONTINUE: int
SEC_I_LOCAL_LOGON: int
SEC_E_BAD_PKGID: int
SEC_E_CONTEXT_EXPIRED: int
SEC_I_CONTEXT_EXPIRED: int
SEC_E_BUFFER_TOO_SMALL: int
SEC_I_RENEGOTIATE: int
SEC_E_WRONG_PRINCIPAL: int
SEC_I_NO_LSA_CONTEXT: int
SEC_E_TIME_SKEW: int
SEC_E_UNTRUSTED_ROOT: int
SEC_E_ILLEGAL_MESSAGE: int
SEC_E_CERT_UNKNOWN: int
SEC_E_CERT_EXPIRED: int
SEC_E_ENCRYPT_FAILURE: int
SEC_E_DECRYPT_FAILURE: int
SEC_E_ALGORITHM_MISMATCH: int
SEC_E_SECURITY_QOS_FAILED: int
SEC_E_UNFINISHED_CONTEXT_DELETED: int
SEC_E_NO_TGT_REPLY: int
SEC_E_NO_IP_ADDRESSES: int
SEC_E_WRONG_CREDENTIAL_HANDLE: int
SEC_E_CRYPTO_SYSTEM_INVALID: int
SEC_E_MAX_REFERRALS_EXCEEDED: int
SEC_E_MUST_BE_KDC: int
SEC_E_STRONG_CRYPTO_NOT_SUPPORTED: int
SEC_E_TOO_MANY_PRINCIPALS: int
SEC_E_NO_PA_DATA: int
SEC_E_PKINIT_NAME_MISMATCH: int
SEC_E_SMARTCARD_LOGON_REQUIRED: int
SEC_E_SHUTDOWN_IN_PROGRESS: int
SEC_E_KDC_INVALID_REQUEST: int
SEC_E_KDC_UNABLE_TO_REFER: int
SEC_E_KDC_UNKNOWN_ETYPE: int
SEC_E_UNSUPPORTED_PREAUTH: int
SEC_E_DELEGATION_REQUIRED: int
SEC_E_BAD_BINDINGS: int
SEC_E_MULTIPLE_ACCOUNTS: int
SEC_E_NO_KERB_KEY: int
ERROR_IPSEC_QM_POLICY_EXISTS: int
ERROR_IPSEC_QM_POLICY_NOT_FOUND: int
ERROR_IPSEC_QM_POLICY_IN_USE: int
ERROR_IPSEC_MM_POLICY_EXISTS: int
ERROR_IPSEC_MM_POLICY_NOT_FOUND: int
ERROR_IPSEC_MM_POLICY_IN_USE: int
ERROR_IPSEC_MM_FILTER_EXISTS: int
ERROR_IPSEC_MM_FILTER_NOT_FOUND: int
ERROR_IPSEC_TRANSPORT_FILTER_EXISTS: int
ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND: int
ERROR_IPSEC_MM_AUTH_EXISTS: int
ERROR_IPSEC_MM_AUTH_NOT_FOUND: int
ERROR_IPSEC_MM_AUTH_IN_USE: int
ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND: int
ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND: int
ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND: int
ERROR_IPSEC_TUNNEL_FILTER_EXISTS: int
ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND: int
ERROR_IPSEC_MM_FILTER_PENDING_DELETION: int
ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION: int
ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION: int
ERROR_IPSEC_MM_POLICY_PENDING_DELETION: int
ERROR_IPSEC_MM_AUTH_PENDING_DELETION: int
ERROR_IPSEC_QM_POLICY_PENDING_DELETION: int
WARNING_IPSEC_MM_POLICY_PRUNED: int
WARNING_IPSEC_QM_POLICY_PRUNED: int
ERROR_IPSEC_IKE_NEG_STATUS_BEGIN: int
ERROR_IPSEC_IKE_AUTH_FAIL: int
ERROR_IPSEC_IKE_ATTRIB_FAIL: int
ERROR_IPSEC_IKE_NEGOTIATION_PENDING: int
ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR: int
ERROR_IPSEC_IKE_TIMED_OUT: int
ERROR_IPSEC_IKE_NO_CERT: int
ERROR_IPSEC_IKE_SA_DELETED: int
ERROR_IPSEC_IKE_SA_REAPED: int
ERROR_IPSEC_IKE_MM_ACQUIRE_DROP: int
ERROR_IPSEC_IKE_QM_ACQUIRE_DROP: int
ERROR_IPSEC_IKE_QUEUE_DROP_MM: int
ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM: int
ERROR_IPSEC_IKE_DROP_NO_RESPONSE: int
ERROR_IPSEC_IKE_MM_DELAY_DROP: int
ERROR_IPSEC_IKE_QM_DELAY_DROP: int
ERROR_IPSEC_IKE_ERROR: int
ERROR_IPSEC_IKE_CRL_FAILED: int
ERROR_IPSEC_IKE_INVALID_KEY_USAGE: int
ERROR_IPSEC_IKE_INVALID_CERT_TYPE: int
ERROR_IPSEC_IKE_NO_PRIVATE_KEY: int
ERROR_IPSEC_IKE_DH_FAIL: int
ERROR_IPSEC_IKE_INVALID_HEADER: int
ERROR_IPSEC_IKE_NO_POLICY: int
ERROR_IPSEC_IKE_INVALID_SIGNATURE: int
ERROR_IPSEC_IKE_KERBEROS_ERROR: int
ERROR_IPSEC_IKE_NO_PUBLIC_KEY: int
ERROR_IPSEC_IKE_PROCESS_ERR: int
ERROR_IPSEC_IKE_PROCESS_ERR_SA: int
ERROR_IPSEC_IKE_PROCESS_ERR_PROP: int
ERROR_IPSEC_IKE_PROCESS_ERR_TRANS: int
ERROR_IPSEC_IKE_PROCESS_ERR_KE: int
ERROR_IPSEC_IKE_PROCESS_ERR_ID: int
ERROR_IPSEC_IKE_PROCESS_ERR_CERT: int
ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ: int
ERROR_IPSEC_IKE_PROCESS_ERR_HASH: int
ERROR_IPSEC_IKE_PROCESS_ERR_SIG: int
ERROR_IPSEC_IKE_PROCESS_ERR_NONCE: int
ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY: int
ERROR_IPSEC_IKE_PROCESS_ERR_DELETE: int
ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR: int
ERROR_IPSEC_IKE_INVALID_PAYLOAD: int
ERROR_IPSEC_IKE_LOAD_SOFT_SA: int
ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN: int
ERROR_IPSEC_IKE_INVALID_COOKIE: int
ERROR_IPSEC_IKE_NO_PEER_CERT: int
ERROR_IPSEC_IKE_PEER_CRL_FAILED: int
ERROR_IPSEC_IKE_POLICY_CHANGE: int
ERROR_IPSEC_IKE_NO_MM_POLICY: int
ERROR_IPSEC_IKE_NOTCBPRIV: int
ERROR_IPSEC_IKE_SECLOADFAIL: int
ERROR_IPSEC_IKE_FAILSSPINIT: int
ERROR_IPSEC_IKE_FAILQUERYSSP: int
ERROR_IPSEC_IKE_SRVACQFAIL: int
ERROR_IPSEC_IKE_SRVQUERYCRED: int
ERROR_IPSEC_IKE_GETSPIFAIL: int
ERROR_IPSEC_IKE_INVALID_FILTER: int
ERROR_IPSEC_IKE_OUT_OF_MEMORY: int
ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED: int
ERROR_IPSEC_IKE_INVALID_POLICY: int
ERROR_IPSEC_IKE_UNKNOWN_DOI: int
ERROR_IPSEC_IKE_INVALID_SITUATION: int
ERROR_IPSEC_IKE_DH_FAILURE: int
ERROR_IPSEC_IKE_INVALID_GROUP: int
ERROR_IPSEC_IKE_ENCRYPT: int
ERROR_IPSEC_IKE_DECRYPT: int
ERROR_IPSEC_IKE_POLICY_MATCH: int
ERROR_IPSEC_IKE_UNSUPPORTED_ID: int
ERROR_IPSEC_IKE_INVALID_HASH: int
ERROR_IPSEC_IKE_INVALID_HASH_ALG: int
ERROR_IPSEC_IKE_INVALID_HASH_SIZE: int
ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG: int
ERROR_IPSEC_IKE_INVALID_AUTH_ALG: int
ERROR_IPSEC_IKE_INVALID_SIG: int
ERROR_IPSEC_IKE_LOAD_FAILED: int
ERROR_IPSEC_IKE_RPC_DELETE: int
ERROR_IPSEC_IKE_BENIGN_REINIT: int
ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY: int
ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN: int
ERROR_IPSEC_IKE_MM_LIMIT: int
ERROR_IPSEC_IKE_NEGOTIATION_DISABLED: int
ERROR_IPSEC_IKE_NEG_STATUS_END: int
CRYPT_E_MSG_ERROR: int
CRYPT_E_UNKNOWN_ALGO: int
CRYPT_E_OID_FORMAT: int
CRYPT_E_INVALID_MSG_TYPE: int
CRYPT_E_UNEXPECTED_ENCODING: int
CRYPT_E_AUTH_ATTR_MISSING: int
CRYPT_E_HASH_VALUE: int
CRYPT_E_INVALID_INDEX: int
CRYPT_E_ALREADY_DECRYPTED: int
CRYPT_E_NOT_DECRYPTED: int
CRYPT_E_RECIPIENT_NOT_FOUND: int
CRYPT_E_CONTROL_TYPE: int
CRYPT_E_ISSUER_SERIALNUMBER: int
CRYPT_E_SIGNER_NOT_FOUND: int
CRYPT_E_ATTRIBUTES_MISSING: int
CRYPT_E_STREAM_MSG_NOT_READY: int
CRYPT_E_STREAM_INSUFFICIENT_DATA: int
CRYPT_I_NEW_PROTECTION_REQUIRED: int
CRYPT_E_BAD_LEN: int
CRYPT_E_BAD_ENCODE: int
CRYPT_E_FILE_ERROR: int
CRYPT_E_NOT_FOUND: int
CRYPT_E_EXISTS: int
CRYPT_E_NO_PROVIDER: int
CRYPT_E_SELF_SIGNED: int
CRYPT_E_DELETED_PREV: int
CRYPT_E_NO_MATCH: int
CRYPT_E_UNEXPECTED_MSG_TYPE: int
CRYPT_E_NO_KEY_PROPERTY: int
CRYPT_E_NO_DECRYPT_CERT: int
CRYPT_E_BAD_MSG: int
CRYPT_E_NO_SIGNER: int
CRYPT_E_PENDING_CLOSE: int
CRYPT_E_REVOKED: int
CRYPT_E_NO_REVOCATION_DLL: int
CRYPT_E_NO_REVOCATION_CHECK: int
CRYPT_E_REVOCATION_OFFLINE: int
CRYPT_E_NOT_IN_REVOCATION_DATABASE: int
CRYPT_E_INVALID_NUMERIC_STRING: int
CRYPT_E_INVALID_PRINTABLE_STRING: int
CRYPT_E_INVALID_IA5_STRING: int
CRYPT_E_INVALID_X500_STRING: int
CRYPT_E_NOT_CHAR_STRING: int
CRYPT_E_FILERESIZED: int
CRYPT_E_SECURITY_SETTINGS: int
CRYPT_E_NO_VERIFY_USAGE_DLL: int
CRYPT_E_NO_VERIFY_USAGE_CHECK: int
CRYPT_E_VERIFY_USAGE_OFFLINE: int
CRYPT_E_NOT_IN_CTL: int
CRYPT_E_NO_TRUSTED_SIGNER: int
CRYPT_E_MISSING_PUBKEY_PARA: int
CRYPT_E_OSS_ERROR: int
KerbDebugRequestMessage: int
KerbQueryTicketCacheMessage: int
KerbChangeMachinePasswordMessage: int
KerbVerifyPacMessage: int
KerbRetrieveTicketMessage: int
KerbUpdateAddressesMessage: int
KerbPurgeTicketCacheMessage: int
KerbChangePasswordMessage: int
KerbRetrieveEncodedTicketMessage: int
KerbDecryptDataMessage: int
KerbAddBindingCacheEntryMessage: int
KerbSetPasswordMessage: int
KerbSetPasswordExMessage: int
KerbVerifyCredentialsMessage: int
KerbQueryTicketCacheExMessage: int
KerbPurgeTicketCacheExMessage: int
KerbRefreshSmartcardCredentialsMessage: int
KerbAddExtraCredentialsMessage: int
KerbQuerySupplementalCredentialsMessage: int
MsV1_0Lm20ChallengeRequest: int
MsV1_0Lm20GetChallengeResponse: int
MsV1_0EnumerateUsers: int
MsV1_0GetUserInfo: int
MsV1_0ReLogonUsers: int
MsV1_0ChangePassword: int
MsV1_0ChangeCachedPassword: int
MsV1_0GenericPassthrough: int
MsV1_0CacheLogon: int
MsV1_0SubAuth: int
MsV1_0DeriveCredential: int
MsV1_0CacheLookup: int
MsV1_0SetProcessOption: int
SEC_E_OK: int
SECBUFFER_MECHLIST: int
SECBUFFER_MECHLIST_SIGNATURE: int
SECPKG_ATTR_ISSUER_LIST_EX: int
SEC_E_INCOMPLETE_CREDENTIALS: int
SEC_E_INCOMPLETE_MESSAGE: int
SEC_I_INCOMPLETE_CREDENTIALS: int



from _typeshed import Incomplete
from typing_extensions import TypeAlias, deprecated

from win32com.server.exception import IsCOMServerException as IsCOMServerException
from win32com.util import IIDToInterfaceName as IIDToInterfaceName

class DispatcherBase:
    policy: Incomplete
    logger: Incomplete
    def __init__(self, policyClass, object) -> None: ...

class DispatcherTrace(DispatcherBase): ...

class DispatcherWin32trace(DispatcherTrace):
    def __init__(self, policyClass, object) -> None: ...

class DispatcherOutputDebugString(DispatcherTrace): ...

@deprecated(
    """\
The DispatcherWin32dbg dispatcher is deprecated!
Please let the developer know if this is a problem.
Uncomment the relevant lines in dispatcher.py to re-enable"""
)
class DispatcherWin32dbg(DispatcherBase):
    def __init__(self, policyClass, ob) -> None: ...

DefaultDebugDispatcher: TypeAlias = DispatcherTrace



from win32.lib.pywintypes import error as error

def ChangeClipboardChain(hWndRemove: int, hWndNewNext: int, /): ...
def CloseClipboard(): ...
def CountClipboardFormats(): ...
def EmptyClipboard(): ...
def EnumClipboardFormats(_format: int = ..., /): ...
def GetClipboardData(_format, /) -> str: ...
def GetClipboardDataHandle(_format, /): ...
def GetClipboardFormatName(_format, /) -> str: ...
def GetClipboardOwner(): ...
def GetClipboardSequenceNumber(): ...
def GetClipboardViewer(): ...
def GetGlobalMemory(hglobal: int, /) -> str: ...
def GetOpenClipboardWindow(): ...
def GetPriorityClipboardFormat(formats, /): ...
def IsClipboardFormatAvailable(format: int, /) -> int: ...
def OpenClipboard(hWnd: int | None = ..., /): ...
def RegisterClipboardFormat(name: str, /): ...
def SetClipboardData(_format, hMem, /): ...
def SetClipboardText(text, _format, /): ...
def SetClipboardViewer(hWndNewViewer: int, /) -> int: ...

CF_BITMAP: int
CF_DIB: int
CF_DIBV5: int
CF_DIF: int
CF_DSPBITMAP: int
CF_DSPENHMETAFILE: int
CF_DSPMETAFILEPICT: int
CF_DSPTEXT: int
CF_ENHMETAFILE: int
CF_HDROP: int
CF_LOCALE: int
CF_MAX: int
CF_METAFILEPICT: int
CF_OEMTEXT: int
CF_OWNERDISPLAY: int
CF_PALETTE: int
CF_PENDATA: int
CF_RIFF: int
CF_SYLK: int
CF_TEXT: int
CF_TIFF: int
CF_UNICODETEXT: int
CF_WAVE: int
UNICODE: bool



from _typeshed import Incomplete
from collections.abc import Iterable

import _win32typing
from win32.lib.pywintypes import error as error

def GetThreadDesktop(ThreadId, /) -> _win32typing.PyHDESK: ...
def EnumWindowStations() -> tuple[tuple[str, Incomplete], ...]: ...
def GetUserObjectInformation(Handle: int, _type, /) -> None: ...
def SetUserObjectInformation(Handle: int, info, _type, /) -> None: ...
def OpenWindowStation(szWinSta, Inherit, DesiredAccess, /) -> _win32typing.PyHWINSTA: ...
def OpenDesktop(szDesktop, Flags, Inherit, DesiredAccess, /) -> _win32typing.PyHDESK: ...
def CreateDesktop(
    Desktop, Flags, DesiredAccess, SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES, /
) -> _win32typing.PyHDESK: ...
def OpenInputDesktop(Flags, Inherit, DesiredAccess, /) -> _win32typing.PyHDESK: ...
def GetProcessWindowStation() -> _win32typing.PyHWINSTA: ...
def CreateWindowStation(
    WindowStation, Flags, DesiredAccess, SecurityAttributes: _win32typing.PySECURITY_ATTRIBUTES, /
) -> _win32typing.PyHWINSTA: ...
def EnumServicesStatus(hSCManager: _win32typing.PySC_HANDLE, ServiceType, ServiceState, /) -> tuple[Incomplete, ...]: ...
def EnumServicesStatusEx(
    SCManager: _win32typing.PySC_HANDLE, ServiceType, ServiceState, InfoLevel, GroupName: Incomplete | None = ..., /
) -> tuple[Incomplete, ...]: ...
def EnumDependentServices(hService: _win32typing.PySC_HANDLE, ServiceState, /) -> tuple[Incomplete, ...]: ...
def QueryServiceConfig(hService: _win32typing.PySC_HANDLE, /): ...
def StartService(hService: _win32typing.PySC_HANDLE, args: Iterable[str] | None, /) -> None: ...
def OpenService(scHandle: _win32typing.PySC_HANDLE, name: str, desiredAccess, /) -> _win32typing.PySC_HANDLE: ...
def OpenSCManager(machineName: str | None, dbName: str | None, desiredAccess: int, /) -> _win32typing.PySC_HANDLE: ...
def CloseServiceHandle(scHandle: _win32typing.PySC_HANDLE, /) -> None: ...
def QueryServiceStatus(hService: _win32typing.PySC_HANDLE, /) -> _win32typing.SERVICE_STATUS: ...
def QueryServiceStatusEx(hService: _win32typing.PySC_HANDLE, /) -> _win32typing.SERVICE_STATUS: ...
def SetServiceObjectSecurity(
    Handle: _win32typing.PySC_HANDLE, SecurityInformation, SecurityDescriptor: _win32typing.PySECURITY_DESCRIPTOR, /
) -> None: ...
def QueryServiceObjectSecurity(
    Handle: _win32typing.PySC_HANDLE, SecurityInformation, /
) -> _win32typing.PySECURITY_DESCRIPTOR: ...
def GetServiceKeyName(hSCManager: _win32typing.PySC_HANDLE, DisplayName, /): ...
def GetServiceDisplayName(hSCManager: _win32typing.PySC_HANDLE, ServiceName, /): ...
def SetServiceStatus(
    scHandle, serviceStatus: _win32typing.SERVICE_STATUS | tuple[int, int, int, int, int, int, int], /
) -> None: ...
def ControlService(scHandle: _win32typing.PySC_HANDLE, code, /) -> _win32typing.SERVICE_STATUS: ...
def DeleteService(scHandle: _win32typing.PySC_HANDLE, /) -> None: ...
def CreateService(
    scHandle: _win32typing.PySC_HANDLE,
    name: str,
    displayName: str,
    desiredAccess: int,
    serviceType: int,
    startType: int,
    errorControl: int,
    binaryFile: str,
    loadOrderGroup: str | None,
    bFetchTag: bool,
    serviceDeps: Iterable[Incomplete] | None,
    acctName: str | None,
    password: str | None,
    /,
) -> _win32typing.PySC_HANDLE: ...
def ChangeServiceConfig(
    hService: _win32typing.PySC_HANDLE,
    serviceType: int,
    startType: int,
    errorControl: int,
    binaryFile: str | None,
    loadOrderGroup: str | None,
    bFetchTag: bool,
    serviceDeps: Iterable[Incomplete] | None,
    acctName: str | None,
    password: str | None,
    displayName: str | None,
    /,
): ...
def LockServiceDatabase(sc_handle: _win32typing.PySC_HANDLE, /): ...
def UnlockServiceDatabase(lock, /): ...
def QueryServiceLockStatus(hSCManager: _win32typing.PySC_HANDLE, /) -> tuple[Incomplete, str, Incomplete]: ...
def ChangeServiceConfig2(hService: _win32typing.PySC_HANDLE, InfoLevel, info, /) -> None: ...
def QueryServiceConfig2(hService: _win32typing.PySC_HANDLE, InfoLevel, /): ...

DBT_CONFIGCHANGECANCELED: int
DBT_CONFIGCHANGED: int
DBT_CUSTOMEVENT: int
DBT_DEVICEARRIVAL: int
DBT_DEVICEQUERYREMOVE: int
DBT_DEVICEQUERYREMOVEFAILED: int
DBT_DEVICEREMOVECOMPLETE: int
DBT_DEVICEREMOVEPENDING: int
DBT_DEVICETYPESPECIFIC: int
DBT_QUERYCHANGECONFIG: int
DF_ALLOWOTHERACCOUNTHOOK: int
SC_ACTION_NONE: int
SC_ACTION_REBOOT: int
SC_ACTION_RESTART: int
SC_ACTION_RUN_COMMAND: int
SC_ENUM_PROCESS_INFO: int
SC_GROUP_IDENTIFIER: int
SC_MANAGER_ALL_ACCESS: int
SC_MANAGER_CONNECT: int
SC_MANAGER_CREATE_SERVICE: int
SC_MANAGER_ENUMERATE_SERVICE: int
SC_MANAGER_LOCK: int
SC_MANAGER_MODIFY_BOOT_CONFIG: int
SC_MANAGER_QUERY_LOCK_STATUS: int
SERVICE_ACCEPT_HARDWAREPROFILECHANGE: int
SERVICE_ACCEPT_NETBINDCHANGE: int
SERVICE_ACCEPT_PARAMCHANGE: int
SERVICE_ACCEPT_PAUSE_CONTINUE: int
SERVICE_ACCEPT_POWEREVENT: int
SERVICE_ACCEPT_PRESHUTDOWN: int
SERVICE_ACCEPT_SESSIONCHANGE: int
SERVICE_ACCEPT_SHUTDOWN: int
SERVICE_ACCEPT_STOP: int
SERVICE_ACTIVE: int
SERVICE_ALL_ACCESS: int
SERVICE_AUTO_START: int
SERVICE_BOOT_START: int
SERVICE_CHANGE_CONFIG: int
SERVICE_CONFIG_DELAYED_AUTO_START_INFO: int
SERVICE_CONFIG_DESCRIPTION: int
SERVICE_CONFIG_FAILURE_ACTIONS: int
SERVICE_CONFIG_FAILURE_ACTIONS_FLAG: int
SERVICE_CONFIG_PRESHUTDOWN_INFO: int
SERVICE_CONFIG_REQUIRED_PRIVILEGES_INFO: int
SERVICE_CONFIG_SERVICE_SID_INFO: int
SERVICE_CONTINUE_PENDING: int
SERVICE_CONTROL_CONTINUE: int
SERVICE_CONTROL_DEVICEEVENT: int
SERVICE_CONTROL_HARDWAREPROFILECHANGE: int
SERVICE_CONTROL_INTERROGATE: int
SERVICE_CONTROL_NETBINDADD: int
SERVICE_CONTROL_NETBINDDISABLE: int
SERVICE_CONTROL_NETBINDENABLE: int
SERVICE_CONTROL_NETBINDREMOVE: int
SERVICE_CONTROL_PARAMCHANGE: int
SERVICE_CONTROL_PAUSE: int
SERVICE_CONTROL_POWEREVENT: int
SERVICE_CONTROL_PRESHUTDOWN: int
SERVICE_CONTROL_SESSIONCHANGE: int
SERVICE_CONTROL_SHUTDOWN: int
SERVICE_CONTROL_STOP: int
SERVICE_DEMAND_START: int
SERVICE_DISABLED: int
SERVICE_DRIVER: int
SERVICE_ENUMERATE_DEPENDENTS: int
SERVICE_ERROR_CRITICAL: int
SERVICE_ERROR_IGNORE: int
SERVICE_ERROR_NORMAL: int
SERVICE_ERROR_SEVERE: int
SERVICE_FILE_SYSTEM_DRIVER: int
SERVICE_INACTIVE: int
SERVICE_INTERACTIVE_PROCESS: int
SERVICE_INTERROGATE: int
SERVICE_KERNEL_DRIVER: int
SERVICE_NO_CHANGE: int
SERVICE_PAUSE_CONTINUE: int
SERVICE_PAUSE_PENDING: int
SERVICE_PAUSED: int
SERVICE_QUERY_CONFIG: int
SERVICE_QUERY_STATUS: int
SERVICE_RUNNING: int
SERVICE_SID_TYPE_NONE: int
SERVICE_SID_TYPE_RESTRICTED: int
SERVICE_SID_TYPE_UNRESTRICTED: int
SERVICE_SPECIFIC_ERROR: int
SERVICE_START: int
SERVICE_START_PENDING: int
SERVICE_STATE_ALL: int
SERVICE_STOP: int
SERVICE_STOP_PENDING: int
SERVICE_STOPPED: int
SERVICE_SYSTEM_START: int
SERVICE_USER_DEFINED_CONTROL: int
SERVICE_WIN32: int
SERVICE_WIN32_OWN_PROCESS: int
SERVICE_WIN32_SHARE_PROCESS: int
UOI_FLAGS: int
UOI_NAME: int
UOI_TYPE: int
UOI_USER_SID: int
WSF_VISIBLE: int
HDESKType = _win32typing.PyHDESK
HWINSTAType = _win32typing.PyHWINSTA
UNICODE: int



from win32.win32gui import *

def GetConsoleWindow() -> int: ...

# Actually returns a list of int|tuple, but lists don't support positional types
def GetWindowRgnBox(hWnd: int, /) -> tuple[int, tuple[int, int, int, int]]: ...
